@@ -10,7 +10,9 @@ import glob
 def reports_pdf_scheduler() -> None:
 
     logger.info("superset_pdf_report started")
-    joblist = glob.glob('{}*.json'.format(PDF_REPORT_JOB_FOLDER))
+    jobspath = '{}*.json'.format(PDF_REPORT_JOB_FOLDER)
+    logger.info(jobspath)
+    joblist = glob.glob(jobspath)
     logger.info(joblist)
 
     for job_name in joblist:
